==> haskell-dense-linear-algebra-0.1.0.0-431-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-J9uWPKRPnR8IN4otzOK49x
key:                  dense-linear-algebra-0.1.0.0-J9uWPKRPnR8IN4otzOK49x
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  bd7419516f5a73c95b453a9b764ce4d5
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-J9uWPKRPnR8IN4otzOK49x
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    math-functions-0.3.4.4-AvUTIYfpNHfD89Fudwn9Jg
    primitive-0.9.1.0-BeRIw0AUz65FDgv1GzpeGd
    vector-0.13.2.0-24VaMY7coOLw3wI0c1W3K
    vector-algorithms-0.9.1.0-39V0dj2zwIa6nCXSt82yNj
    vector-binary-instances-0.2.5.2-6NT0F6Ki8ti4Z1PF3G9oPd
    vector-th-unbox-0.2.2-1xl3xBa9Qo6CwiJpwEfg30

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dense-linear-algebra-0.1.0.0-432-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dense-linear-algebra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dense-linear-algebra
version:              0.1.0.0
visibility:           public
id:                   dense-linear-algebra-0.1.0.0-BZ6f9DNJ9z5Jq6XGQA5K6u
key:                  dense-linear-algebra-0.1.0.0-BZ6f9DNJ9z5Jq6XGQA5K6u
license:              BSD-2-Clause
copyright:            2018 Author name here
maintainer:           Alexey Khudaykov <alexey.skladnoy@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
synopsis:
    Simple and incomplete pure haskell implementation of linear algebra

description:
    This library is simply collection of linear-algebra related modules
    split from statistics library.

category:             Math, Statistics, Numeric
abi:                  8ad9fb91a6b4f8f6de99e3ac5793da26
exposed:              True
exposed-modules:
    Statistics.Matrix Statistics.Matrix.Algorithms
    Statistics.Matrix.Function Statistics.Matrix.Mutable
    Statistics.Matrix.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dense-linear-algebra-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dense-linear-algebra
hs-libraries:         HSdense-linear-algebra-0.1.0.0-BZ6f9DNJ9z5Jq6XGQA5K6u
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    math-functions-0.3.4.4-Fh4MI4RdNPf9U0T3g6DnjH
    primitive-0.9.1.0-CAiXP181yOJM9BA05PVbs
    vector-0.13.2.0-JUxTFkVHiOCDvdzFqkdqvm
    vector-algorithms-0.9.1.0-L2fdwl7zb1gK4A2ZpsqYA
    vector-binary-instances-0.2.5.2-LhDqhdNXTY9Eat8zeHNuyX
    vector-th-unbox-0.2.2-JoNs7gInXKJJcwdwcMZXJn

haddock-interfaces:
    /usr/share/doc/haskell-dense-linear-algebra/html/dense-linear-algebra.haddock

haddock-html:         /usr/share/doc/haskell-dense-linear-algebra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
